from pathlib import Path
import tomllib

CONTENT_DIR = None
TEMPLATES_DIR = None
STYLES_DIR = None

class Configuration:

    def __init__(self, config_path):
        self.config_path = config_path

        self.content_dir: Path = None
        self.templates_dir: Path = None
        self.styles_dir: Path = None

        self.listen_address: str = "127.0.0.1"
        self.listen_port: int = 8080
        self.debug: bool = False
        self.access_log: bool = True
        self.max_threads: int = 4
        self.admin_browser: bool = False
        self.admin_password: str = None

    def load_config(self):
        try:
            with open(self.config_path, "rb") as f:
                self.config_data = tomllib.load(f)
        except FileNotFoundError:
            raise FileNotFoundError(f"Config file not found at {self.config_path}")
        except tomllib.TOMLDecodeError:
            raise tomllib.TOMLDecodeError(f"Config file at {self.config_path} is not valid TOML")
        
        paths = self.config_data.get("paths", {})
        if not paths:
            raise ValueError("Config file does not contain paths section")
        
        self.content_dir = paths.get("content_dir")
        if not self.content_dir:
            raise ValueError("Config file does not contain content_dir path")
        self.content_dir = Path(self.content_dir)

        self.templates_dir = paths.get("templates_dir")
        if not self.templates_dir:
            raise ValueError("Config file does not contain templates_dir path")
        self.templates_dir = Path(self.templates_dir)

        self.styles_dir = paths.get("styles_dir")
        if not self.styles_dir:
            raise ValueError("Config file does not contain styles_dir path")
        self.styles_dir = Path(self.styles_dir)

        server = self.config_data.get("server", {})
        if not server:
            raise ValueError("Config file does not contain server section")
        
        self.listen_address = server.get("listen_address", self.listen_address)
        self.listen_port = server.get("listen_port", self.listen_port)
        self.debug = server.get("debug", self.debug)
        self.access_log = server.get("access_log", self.access_log)
        self.max_threads = server.get("max_threads", self.max_threads)
        self.admin_browser = server.get("admin_browser", self.admin_browser)
        self.admin_password = server.get("admin_password", self.admin_password)
        
    def set_globals(self):
        global CONTENT_DIR, TEMPLATES_DIR, STYLES_DIR
        CONTENT_DIR = self.content_dir
        TEMPLATES_DIR = self.templates_dir
        STYLES_DIR = self.styles_dir


